dfvfs.serializer package
========================

Submodules
----------

dfvfs.serializer.json\_serializer module
----------------------------------------

.. automodule:: dfvfs.serializer.json_serializer
   :members:
   :undoc-members:
   :show-inheritance:

dfvfs.serializer.serializer module
----------------------------------

.. automodule:: dfvfs.serializer.serializer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dfvfs.serializer
   :members:
   :undoc-members:
   :show-inheritance:
